#!/usr/bin/python

##
# build-test.py [--verbose]
#
# reads the output of exiv2 -v -V and inspects it for sanity
# inspect run-library libraries platform/compiler/{debug|release}{shared|static}
# TODO: 1 report loaded libraries that we didn't expect
#       2 mingw support
##

import os
import sys
import subprocess

##
#   print error msg and terminate
def error(msg):
    print '***',msg,'***'
    sys.exit(1)

##
#   run a command and return output string
def runCommand(command):
    ##
    # don't use check_output 
    #           this is 2.7 feature.
    #           not available on cygwin's default python 2.6.8 interpreter
    #           result=subprocess.check_output( command.split(' '))
    ##

    result  =subprocess.Popen(command.split(' '), stdout=subprocess.PIPE).communicate()[0]

    # ensure lines are \n terminated (remove \r bytes)
    return result.replace('\r\n', '\n').replace('\r', '\n')

##
#   process the version information dictionary
def platform(dict):
    verbose=dict.has_key('verbose')
    for k in sorted(dict.keys()):
        v=dict[k]
        if type(v)==type([]):
            v='['+str(len(v))+']'
        if verbose:
            print "%-20s -> %s" % (k,v)

##
#   search dict for an array of libraries
def expect(dict,expects):
    verbose=dict.has_key('verbose')
    libs=dict['library']
    E={};
    for e in expects:
        e=e.lower().replace('-','.')      # cygwin uses '-' in versioning
        e=e.split('.')[0]
        if verbose:
            print 'expect library',e
        E[e]=0
        
    for lib in libs:
        lib=lib.lower().replace('\\','/') # cygwin uses '\' in pathnames
        lib=lib.replace('-','.')
        lib=os.path.basename(lib).split('.')[0]
        if E.has_key(lib):
            E[lib]=E[lib]+1
            if verbose:
                print 'found  library',lib
    for e in E.keys():
        if E[e]==0:
            error( "expected library '%s' not found" % e )

## 
def apple(dict):
    expects= [ 'libSystem.B.dylib'
             , 'libexpat.1.dylib'
             , 'libz.1.dylib'
             , 'libiconv.2.dylib'
             , 'libdyld.dylib'
             , 'libc++.1.dylib'
             # , 'libstdc++.6.dylib' # I suspect this is only with GCC (Xcode4 and earlier)
             ] ;

    # which version of MacOS-X ?
    os_major=int(os.uname()[2].split('.')[0])
    os_minor=int(os.uname()[2].split('.')[1])
    NC=13;ML=12;LION=11;SL=10;LEO=9;

    if dict['dll']:
        expects.append('libexiv2.12.dylib')
    
        ## Mountain Lion
        if os_major==ML and dict['dll']:
            expects.append('libexiv2.12.dylib')
            expects.append('libSystem.B.dylib')
            expects.append('libexpat.1.dylib')
            expects.append('libz.1.dylib')
            expects.append('libiconv.2.dylib')
            expects.append('libstdc++.6.dylib')
            expects.append('libdyld.dylib')
            expects.append('libc++.1.dylib')

    expect(dict,expects)

    expect_bits = 32 if os_major==LEO else 64
    if expect_bits != dict['bits']:
        error('*** expected %d bit build ***' % expect_bits)

##
def linux(dict):
    expects = [ 'libdl.so.2'
              , 'libexiv2.so.12'
              , 'libstdc++.so.6'
              , 'libm.so.6'
              , 'libgcc_s.so.1'
              , 'libc.so.6'
              , 'libz.so.1'
              , 'libexpat.so.1'
              ]
    expect(dict,expects)
    
## 
def windows(dict):
    expects = [ 'ntdll.dll'
              , 'kernel32.dll'
              , 'kernelbase.dll'
              , 'psapi.dll'
              ];
    if dict['dll']:
        dll='d.dll' if dict['debug'] else '.dll' 
        expects.append( 'exiv2' + dll )
        expects.append( 'zlib1' + dll ) 
        expects.append('libexpat.dll' )

        # c run time libraries
        # 2003=71, 2005=80, 2008=90, 2010=100
        v=int( float(dict['version'])*10 )
        expects.append('msvcr%d%s' % (v,dll) )
        expects.append('msvcp%d%s' % (v,dll) )

    expect(dict,expects)

## 
def cygwin(dict):
    expects = [ 'ntdll.dll'
              , 'kernel32.dll'
              , 'kernelbase.dll'
              , 'cygexiv2-12.dll'
              , 'cygwin1.dll'
              , 'cyggcc_s-1.dll'
              , 'cygstdc++-6.dll'
              , 'psapi.dll'
              , 'cygexpat-1.dll'
              , 'cygiconv-2.dll'
              , 'cygintl-8.dll'
              ];
    expect(dict,expects)

## 
def mingw(dict):
    error("can't test platform mingw")

## 
def unknown(dict):
    error("can't test platform unknown")

##
def main(args):
    this=os.path.abspath(args[0])

    ##
    # find the exiv2 executable
    exiv2='exiv2'
    if os.environ.has_key('EXIV2_BINDIR'):
        exiv2=os.path.abspath(os.path.join(os.environ['EXIV2_BINDIR'],exiv2))
    else:
        exiv2=os.path.join(os.path.dirname(this),'../bin',exiv2)
        
    ##
    # collect the version dictionary from exiv2
    dict={}
    verbose=False
    for arg in args:
        if arg == '--verbose':
            verbose=True
            dict['verbose']=True
    
    if os.path.exists(exiv2):
        output = runCommand(exiv2 + ' -v -V')
        if verbose: 
            print output
        lines = output.split('\n')
        for l in lines:
            kv=l.split('=')
            if len(kv)==2:
                k=kv[0]
                v=kv[1]
                if not dict.has_key(k):
                    dict[k]=[]
                dict[k].append(v)

        # flatten value arrays of length 1
        for k in dict.keys():
            if type(dict[k])==type([]): 
                if len(dict[k])==1:
                    dict[k]=dict[k][0]
                    
        # convert numeric strings to ints
        debug='debug'
        dll='dll'
        bits='bits'
        dict[dll  ] = int(dict[dll])
        dict[debug] = int(dict[debug])
        dict[bits ] = int(dict[bits])

        ##
        # analyse the version dictionary
        platform(dict)
        eval(dict['platform']+'(dict)')

        ##
        # report
        v='Release' if dict[debug]==0 else 'Debug'
        d='DLL'     if dict[dll  ]==0 else ''
        print "build %dbit %-8s  %-12s looks good" % (dict[bits],dict['platform'],v+d)
    else:
        error("exiv2 not found!")

if __name__ == '__main__':
    main(sys.argv)

# That's all Folks!
##


# -*- coding: utf-8 -*-

import system_tests


@system_tests.CopyFiles("$data_path/exiv2-empty.jpg")
class EasyaccessTest(metaclass=system_tests.CaseMeta):

    filename = "$data_path/exiv2-empty_copy.jpg"

    commands = [
        """$exiv2 -u -v -M"set Exif.Image.Make Samsung" $filename""",
        "$easyaccess_test $filename"
    ]
    stdout = [
        """File 1/1: $filename
Set Exif.Image.Make "Samsung" (Ascii)
""",
         """Orientation          (                                   ) : 
ISO speed            (                                   ) : 
Flash bias           (                                   ) : 
Exposure mode        (                                   ) : 
Scene mode           (                                   ) : 
Macro mode           (                                   ) : 
Image quality        (                                   ) : 
White balance        (                                   ) : 
Lens name            (                                   ) : 
Saturation           (                                   ) : 
Sharpness            (                                   ) : 
Contrast             (                                   ) : 
Scene capture type   (                                   ) : 
Metering mode        (                                   ) : 
Camera make          (Exif.Image.Make                    ) : Samsung
Camera model         (                                   ) : 
Exposure time        (                                   ) : 
FNumber              (                                   ) : 
Subject distance     (                                   ) : 
Camera serial number (                                   ) : 
Focal length         (                                   ) : 
AF point             (                                   ) : 
"""
    ]
    stderr = [""] * 2
    retval = [0] * 2



# -*- coding: utf-8 -*-

import system_tests


class TestCvePoC(metaclass=system_tests.CaseMeta):

    url = "https://github.com/Exiv2/exiv2/issues/188"
    found_by = ["Wei You", "@youwei1988"]

    filename = "$data_path/poc_2017-12-12_issue188"
    commands = ["$exiv2 " + filename]
    stdout = [""]
    stderr = ["""$exiv2_overflow_exception_message """ + filename + """:
$addition_overflow_message
"""]
    retval = [1]



#!/usr/bin/python3
# -*- coding: utf-8 -*-

import itertools
import multiprocessing
import os
import shlex
import subprocess
import sys

#: -DEXIV2_BUILD_SHARED_LIBS options
SHARED_LIBS = ["ON", "OFF"]

#: C & C++ compiler as tuples
CCS = ["gcc", "clang"]

#: -DCMAKE_BUILD_TYPE options
BUILD_TYPES = ["Debug", "Release"]

#: Additional parameters for cmake
CMAKE_OPTIONS = os.getenv("CMAKE_OPTIONS") or \
    "-DEXIV2_TEAM_EXTRA_WARNINGS=ON -DEXIV2_ENABLE_VIDEO=ON "\
    "-DEXIV2_ENABLE_WEBREADY=ON -DEXIV2_BUILD_UNIT_TESTS=ON "\
    "-DBUILD_WITH_CCACHE=ON "

#: cpu count
NCPUS = multiprocessing.cpu_count()


def call_wrapper(*args, **kwargs):
    """
    Wrapper around subprocess.call which terminates the program on non-zero
    return value.
    """
    return_code = subprocess.call(*args, **kwargs)
    if return_code != 0:
        sys.exit(return_code)


# create build directory
os.mkdir("build")

root_dir = os.path.abspath(os.getcwd())

for params in itertools.product(SHARED_LIBS, CCS, BUILD_TYPES):

    lib_type, cc, build_type = params

    cxx = {"gcc": "g++", "clang": "clang++"}[cc]

    cwd = os.path.abspath(os.path.join("build", "_".join(params)))
    os.mkdir(cwd)

    cmake = "cmake {!s} -DCMAKE_BUILD_TYPE={build_type} "\
        "-DBUILD_SHARED_LIBS={lib_type} ../.."\
        .format(CMAKE_OPTIONS, build_type=build_type, lib_type=lib_type)
    make = "make -j " + str(NCPUS)
    make_tests = "make tests"
    unit_tests = os.path.join(cwd, "bin", "unit_tests")

    # set up environment
    env_copy = os.environ.copy()
    env_copy["CC"] = cc
    env_copy["CXX"] = cxx

    # location of the binaries for the new test suite:
    env_copy["EXIV2_BINDIR"] = os.path.join(cwd, "bin")

    kwargs = {"env": env_copy, "cwd": cwd}

    def run(cmd):
        call_wrapper(shlex.split(cmd), **kwargs)

    run(cmake)
    run(make)
    run(make_tests)
    run(unit_tests)



# -*- coding: utf-8 -*-

import system_tests


class TestCvePoC(metaclass=system_tests.CaseMeta):

    url = "https://github.com/Exiv2/exiv2/issues/76"

    filename = "$data_path/010_bad_free"
    commands = ["$exiv2 $filename"]
    retval = [0]
    stdout = [
        """File name       : $filename
File size       : 20274 Bytes
MIME type       : image/tiff
Image size      : 12336 x 12336
Camera make     : 00000000
Camera model    : 000000000000
Image timestamp : 
Image number    : 
Exposure time   : 
Aperture        : 
Exposure bias   : 
Flash           : 
Flash bias      : 
Focal length    : 
Subject distance: 
ISO speed       : 
Exposure mode   : 
Metering mode   : 
Macro mode      : 
Image quality   : 
Exif Resolution : 12336 x 12336
White balance   : 
Thumbnail       : None
Copyright       : 00000
Exif comment    : 

"""
    ]
    stderr = [
        """Warning: Directory Image, entry 0x0111: Strip 0 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 1 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 2 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 3 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 4 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 5 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 6 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 7 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 8 is outside of the data area; ignored.
Warning: Directory Image, entry 0x0111: Strip 9 is outside of the data area; ignored.
Error: Offset of directory Image, entry 0x0132 is out of bounds: Offset = 0x30003030; truncating the entry
Error: Directory Image, entry 0x8649 has invalid size 4294967295*1; skipping entry.
Error: Directory Image, entry 0x8769 Sub-IFD pointer 0 is out of bounds; ignoring it.
Error: XMP Toolkit error 201: XML parsing failure
Warning: Failed to decode XMP metadata.
"""
    ]



# -*- coding: utf-8 -*-

import system_tests


class TestCvePoC(metaclass=system_tests.CaseMeta):

    url = "https://github.com/Exiv2/exiv2/issues/60"

    filename = "$data_path/POC13"
    commands = ["$exiv2 $filename"]
    stdout = [
        """File name       : $filename
File size       : 60 Bytes
MIME type       : image/x-olympus-orf
Image size      : 0 x 0
Camera make     : 
Camera model    : 
Image timestamp : 
Image number    : 
Exposure time   : 
Aperture        : 
Exposure bias   : 
Flash           : 
Flash bias      : 
Focal length    : 
Subject distance: 
ISO speed       : 
Exposure mode   : 
Metering mode   : 
Macro mode      : 
Image quality   : 
Exif Resolution : 
White balance   : 
Thumbnail       : None
Copyright       : 
Exif comment    : 

"""
    ]
    stderr = [
        """Error: Offset of directory Image, entry 0x0000 is out of bounds: Offset = 0x7e000000; truncating the entry
Error: Offset of directory Image, entry 0x0117 is out of bounds: Offset = 0x4f524900; truncating the entry
Error: Directory Image, entry 0x0004 has invalid size 4294967289*2; skipping entry.
Error: Offset of directory Image, entry 0x0100 is out of bounds: Offset = 0x0012ff00; truncating the entry
"""
    ]
    retval = [0]



# -*- coding: utf-8 -*-

import system_tests


class TestCvePoC(metaclass=system_tests.CaseMeta):

    url = "https://github.com/Exiv2/exiv2/issues/54"

    filename = "$data_path/POC7"
    commands = ["$exiv2 $filename"]
    stdout = [
        """File name       : $filename
File size       : 632 Bytes
MIME type       : image/tiff
Image size      : 0 x 0
Camera make     : 
Camera model    : 
Image timestamp : 
Image number    : 
Exposure time   : 
Aperture        : 
Exposure bias   : 
Flash           : 
Flash bias      : 
Focal length    : 
Subject distance: 
ISO speed       : 
Exposure mode   : 
Metering mode   : 
Macro mode      : 
Image quality   : 
Exif Resolution : 
White balance   : 
Thumbnail       : None
Copyright       : 
Exif comment    : 

"""
    ]
    stderr = [
        """Error: Directory Image, entry 0x0000 has invalid size 1229520896*8; skipping entry.
Error: Directory Image, entry 0x0000 has invalid size 1447624704*8; skipping entry.
Error: Directory Image, entry 0x0111 has invalid size 4294967295*2; skipping entry.
Warning: Directory Image, entry 0x0111: Size or data offset value not set, ignoring them.
"""
    ]
    retval = [0]



# -*- coding: utf-8 -*-

if __name__ == '__main__':

    import argparse
    import os
    import unittest
    import sys

    import system_tests

    parser = argparse.ArgumentParser(description="The system test suite")

    parser.add_argument(
        "--config_file",
        type=str,
        nargs=1,
        help="Path to the suite's configuration file",
        default=['suite.conf']
    )
    parser.add_argument(
        "--verbose", "-v",
        action='count',
        help="verbosity level",
        default=1
    )
    parser.add_argument(
        "--debug",
        help="enable debugging output",
        action='store_true'
    )

    parser.add_argument(
        "dir_or_file",
        help="root directory under which the testsuite searches for tests or a"
        "single file which tests are run (defaults to the config file's"
        "location)",
        default=None,
        type=str,
        nargs='?'
    )

    args = parser.parse_args()
    conf_file = args.config_file[0]
    DEFAULT_ROOT = os.path.abspath(os.path.dirname(conf_file))

    system_tests.set_debug_mode(args.debug)
    system_tests.configure_suite(conf_file)

    if args.dir_or_file is None or os.path.isdir(args.dir_or_file):
        discovered_tests = unittest.defaultTestLoader.discover(
            args.dir_or_file or DEFAULT_ROOT
        )
    elif os.path.isfile(args.dir_or_file):
        discovered_tests = unittest.defaultTestLoader.discover(
            os.path.dirname(args.dir_or_file),
            pattern=os.path.split(args.dir_or_file)[1],
        )
    else:
        print(
            "WARNING: Invalid search location, falling back to {!s}"
            .format(DEFAULT_ROOT),
            file=sys.stderr
        )
        discovered_tests = unittest.defaultTestLoader.discover(
            DEFAULT_ROOT
        )

    test_res = unittest.runner.TextTestRunner(verbosity=args.verbose)\
                              .run(discovered_tests)

    sys.exit(0 if len(test_res.failures) + len(test_res.errors) == 0 else 1)



# -*- coding: utf-8 -*-

import system_tests

class TestFirstPoC(metaclass=system_tests.CaseMeta):
    """
    Regression test for the first bug described in:
    https://github.com/Exiv2/exiv2/issues/247
    """
    url = "https://github.com/Exiv2/exiv2/issues/247"

    filename = "$data_path/2-invalid-memory-access"
    commands = ["$exiv2 -pt " + filename]
    stdout = [
        """Exif.Image.Make                              Ascii       6  Canon
Exif.Image.Orientation                       Short       1  top, left
Exif.Image.XResolution                       Rational    1  180
Exif.Image.YResolution                       Rational    1  180
Exif.Image.ResolutionUnit                    Short       1  inch
Exif.Image.DateTime                          Ascii      20  2003:12:14 12:01:44
Exif.Image.YCbCrPositioning                  Short       1  Centered
Exif.Image.ExifTag                           Long        1  196
Exif.Photo.ExposureTime                      Rational    1  1/500 s
Exif.Photo.FNumber                           Rational    1  F4.9
Exif.Photo.ExifVersion                       Undefined   4  2.20
Exif.Photo.DateTimeOriginal                  Ascii      20  2003:12:14 12:01:44
Exif.Photo.DateTimeDigitized                 Ascii      20  2003:12:14 12:01:44
Exif.Photo.ComponentsConfiguration           Undefined   4  YCbCr
Exif.Photo.CompressedBitsPerPixel            Rational    1  5
Exif.Photo.ShutterSpeedValue                 SRational   1  1/501 s
Exif.Photo.ApertureValue                     Rational    1  F5
Exif.Photo.ExposureBiasValue                 SRational   1  0 EV
Exif.Photo.MaxApertureValue                  Rational    1  F2.8
Exif.Photo.MeteringMode                      Short       1  Center weighted average
Exif.Photo.Flash                             Short       1  No, auto
Exif.Photo.FocalLength                       Rational    1  21.3 mm
Exif.Photo.MakerNote                         Undefined 450  (Binary value suppressed)
Exif.MakerNote.Offset                        Long        1  942
Exif.MakerNote.ByteOrder                     Ascii       3  II
Exif.CanonCs.Macro                           Short       1  Off
Exif.CanonCs.Selftimer                       Short       1  Off
Exif.CanonCs.Quality                         Short       1  Superfine
Exif.CanonCs.FlashMode                       Short       1  Auto
Exif.CanonCs.DriveMode                       Short       1  Single / timer
Exif.CanonCs.FocusMode                       Short       1  Single
Exif.CanonCs.ImageSize                       Short       1  Large
Exif.CanonCs.EasyMode                        Short       1  Manual
Exif.CanonCs.DigitalZoom                     Short       1  None
Exif.CanonCs.Contrast                        Short       1  Normal
Exif.CanonCs.Saturation                      Short       1  Normal
Exif.CanonCs.Sharpness                       Short       1  Normal
Exif.CanonCs.ISOSpeed                        Short       1  100
Exif.CanonCs.MeteringMode                    Short       1  Center-weighted average
Exif.CanonCs.FocusType                       Short       1  Auto
Exif.CanonCs.AFPoint                         Short       1  Center
Exif.CanonCs.ExposureProgram                 Short       1  Program (P)
Exif.CanonCs.LensType                        Short       1  n/a
Exif.CanonCs.Lens                            Short       3  7.1 - 21.3 mm
Exif.CanonCs.MaxAperture                     Short       1  F5
Exif.CanonCs.MinAperture                     Short       1  F8
Exif.CanonCs.FlashActivity                   Short       1  Did not fire
Exif.CanonCs.FlashDetails                    Short       1  
Exif.CanonCs.FocusContinuous                 Short       1  Single
Exif.CanonCs.AESetting                       Short       1  Normal AE
Exif.CanonCs.ImageStabilization              Short       1  (65535)
Exif.CanonCs.DisplayAperture                 Short       1  49
Exif.CanonCs.ZoomSourceWidth                 Short       1  2272
Exif.CanonCs.ZoomTargetWidth                 Short       1  2272
Exif.CanonCs.SpotMeteringMode                Short       1  AF Point
Exif.Canon.FocalLength                       Short       4  21.3 mm
Exif.CanonSi.ISOSpeed                        Short       1  100
Exif.CanonSi.MeasuredEV                      Short       1  13.63
Exif.CanonSi.TargetAperture                  Short       1  F5
Exif.CanonSi.TargetShutterSpeed              Short       1  1/501 s
Exif.CanonSi.WhiteBalance                    Short       1  Auto
Exif.CanonSi.Sequence                        Short       1  0
Exif.CanonSi.AFPointUsed                     Short       1  3 focus points; center used
Exif.CanonSi.FlashBias                       Short       1  0 EV
Exif.CanonSi.SubjectDistance                 Short       1  7.82 m
Exif.CanonSi.ApertureValue                   Short       1  F5
Exif.CanonSi.ShutterSpeedValue               Short       1  1/523 s
Exif.CanonSi.MeasuredEV2                     Short       1  -6.00
Exif.Canon.ImageType                         Ascii      32  IMG:PowerShot S40 JPEG
Exif.Canon.FirmwareVersion                   Ascii      24  Firmware Version 1.10
Exif.Canon.FileNumber                        Long        1  117-1771
Exif.Canon.OwnerName                         Ascii      32  Andreas Huggel
Exif.Canon.ModelID                           Long        1  PowerShot S40
Exif.Canon.CameraInfo                        Short      21  42 3 32769 378 32769 0 0 0 259 2 0 10 0 0 0 57 198 5 0 0 0
Exif.Photo.UserComment                       Undefined 264  (Binary value suppressed)
Exif.Photo.FlashpixVersion                   Undefined   4  1.00
Exif.Photo.ColorSpace                        Short       1  sRGB
Exif.Photo.PixelXDimension                   Short       1  2272
Exif.Photo.PixelYDimension                   Short       1  1704
Exif.Photo.InteroperabilityTag               Long        1  1416
Exif.Iop.InteroperabilityIndex               Ascii       4  R98
Exif.Iop.InteroperabilityVersion             Undefined   4  1.00
Exif.Iop.RelatedImageWidth                   Short       1  2272
Exif.Iop.RelatedImageLength                  Short       1  1704
Exif.Photo.FocalPlaneXResolution             Rational    1  8114.29
Exif.Photo.FocalPlaneYResolution             Rational    1  8114.29
Exif.Photo.FocalPlaneResolutionUnit          Short       1  inch
Exif.Photo.SensingMethod                     Short       1  One-chip color area
Exif.Photo.FileSource                        Undefined   1  Digital still camera
Exif.Photo.CustomRendered                    Short       1  Normal process
Exif.Photo.ExposureMode                      Short       1  Auto
Exif.Photo.WhiteBalance                      Short       1  Auto
Exif.Photo.DigitalZoomRatio                  Rational    1  1.0
Exif.Photo.SceneCaptureType                  Short       1  Standard
Exif.Thumbnail.Compression                   Short       1  JPEG (old-style)
Exif.Thumbnail.XResolution                   Rational    1  180
Exif.Thumbnail.YResolution                   Rational    1  180
Exif.Thumbnail.ResolutionUnit                Short       1  inch
Exif.Thumbnail.JPEGInterchangeFormat         Long        1  2036
Exif.Thumbnail.JPEGInterchangeFormatLength   Long        1  5448
"""]
    stderr = [""]
    retval = [0]



from conans import ConanFile
from conans.tools import os_info

class Exiv2Conan(ConanFile):
    settings = 'os', 'compiler', 'build_type', 'arch'
    generators = 'cmake'
    options = {'unitTests': [True, False],
               'xmp': [True, False],
               'iconv': [True, False],
               'webready': [True, False],
              }
    default_options = ('unitTests=True',
                       'xmp=False',
                       'iconv=False',
                       'webready=False',
                      )

    def configure(self):
        self.options['libcurl'].shared = False
        self.options['libcurl'].with_openssl = True
        self.options['gtest'].shared = True

    def requirements(self):
        self.requires('zlib/1.2.11@conan/stable')

        if os_info.is_windows and self.options.iconv:
            self.requires('libiconv/1.15@bincrafters/stable')

        if self.options.unitTests:
            self.requires('gtest/1.8.0@bincrafters/stable')

        if self.options.webready:
            self.requires('libcurl/7.60.0@bincrafters/stable')

        if self.options.xmp:
            self.requires('XmpSdk/2016.7@piponazo/stable') # from conan-piponazo
        else:
            self.requires('Expat/2.2.6@pix4d/stable')

    def imports(self):
        self.copy('*.dll', dst='conanDlls', src='bin')
        self.copy('*.dylib', dst='bin', src='lib')
